@@ -147,6 +147,11 @@ struct enqi : public MethNoargs<enqi, wrpy_Var>
     constexpr static const char* signature = "";
     constexpr static const char* returns = "int";
     constexpr static const char* summary = "get the value of the variable, as an int";
+    constexpr static const char* doc = R"(If the variable is a scaled decimal value,
+this returns its unscaled integer representation. This provides a way to work
+with the exact underlying representation of values, without dealing with the
+potential limitations of floating point representations.
+)";
 
     static PyObject* run(Impl* self)
     {
@@ -177,6 +182,11 @@ struct enqc : public MethNoargs<enqc, wrpy_Var>
     constexpr static const char* signature = "";
     constexpr static const char* returns = "str";
     constexpr static const char* summary = "get the value of the variable, as a str";
+    constexpr static const char* doc = R"(If the variable is a scaled decimal value,
+this returns its unscaled integer representation. This provides a way to work
+with the exact underlying representation of values, without dealing with the
+potential limitations of floating point representations.
+)";
 
     static PyObject* run(Impl* self)
     {
@@ -299,7 +309,7 @@ struct get : public MethKwargs<get, wrpy_Var>
     constexpr static const char* name = "get";
     constexpr static const char* signature = "default: Any=None";
     constexpr static const char* returns = "Union[str, float, long, Any]";
-    constexpr static const char* summary = "get the value of the variable, with a default if it is unset";
+    constexpr static const char* summary = "get the value of the variable. If the variable is unset, ``default`` is returned";
 
     static PyObject* run(Impl* self, PyObject* args, PyObject* kw)
     {
@@ -347,26 +357,39 @@ struct VarDef : public Type<VarDef, wrpy_Var>
     constexpr static const char* qual_name = "wreport.Var";
     constexpr static const char* doc = R"(
 Var holds a measured value, which can be integer, float or string, and
-a `wreport.Varinfo`_ with all available information (description, unit,
+a :class:`Varinfo` with all available information (description, unit,
 precision, ...) related to it.
 
-Var objects can be created from a `wreport.Varinfo`_ object, and an
+Var objects can be created from a :class:`Varinfo` object, and an
 optional value. Omitting the value creates an unset variable.
 
 Examples::
 
+    table = wreport.Vartable.get_bufr(master_table_version_number=24)
     v = wreport.Var(table["B12101"], 32.5)
     # v.info returns detailed informations about the variable in a Varinfo object.
     print("%s: %s %s %s" % (v.code, str(v), v.info.unit, v.info.desc))
+
+**Constructor**: Var(varinfo: Union[wreport.Varinfo, wreport.Var], value: Union[str, int, float] = None)
+
+:arg varinfo: :class:`Varinfo` or :class:`Var` to use to create the variable
+:arg value: value for the variable
+
+If the variable is a scaled decimal, getting and setting its value using
+integers or strings will use the raw unscaled representation of its value.
+This provides a way to work with the exact underlying representation of values,
+without dealing with the potential limitations of floating point
+representations.
 )";
     GetSetters<code, isset, info> getsetters;
     Methods<enqi, enqd, enqc, enq, enqa, seta, unseta, get_attrs, get, format> methods;
 
     static int _init(Impl* self, PyObject* args, PyObject* kw)
     {
+        static const char* kwlist[] = { "varinfo", "value", nullptr };
         PyObject* varinfo_or_var = nullptr;
         PyObject* val = nullptr;
-        if (!PyArg_ParseTuple(args, "O|O", &varinfo_or_var, &val))
+        if (!PyArg_ParseTupleAndKeywords(args, kw, "O|O", const_cast<char**>(kwlist), &varinfo_or_var, &val))
             return -1;
 
         try {
