@@ -2,8 +2,11 @@
 #include "trace.h"
 #include "wreport/bulletin/associated_fields.h"
 #include <cstdarg>
+#include <algorithm>
+#include <regex.h>
 
 namespace {
+
 const char* bufr_sec_names[] = {
     "Indicator section",
     "Identification section",
@@ -18,11 +21,13 @@ static inline uint32_t all_ones(int bitlen)
 {
     return ((1 << (bitlen - 1))-1) | (1 << (bitlen - 1));
 }
+
 }
 
 namespace wreport {
 namespace bufr {
 
+
 Input::Input(const std::string& in)
 {
     data = (const unsigned char*)in.data();
@@ -64,23 +69,46 @@ void Input::scan_other_sections(bool has_optional)
     s4_cursor = sec[4] + 4;
 }
 
-void Input::debug_dump_next_bits(const char* desc, int count) const
+void Input::debug_dump_next_bits(const char* desc, unsigned count, const std::vector<unsigned>& groups) const
 {
+    static const char* cols[] = { "\033[33m", "\033[37m" };
+    unsigned cols_pos = 0;
+    unsigned cols_size = 2;
     fputs(desc, stderr);
     size_t cursor = s4_cursor;
     int pbyte = this->pbyte;
     int pbyte_len = this->pbyte_len;
-    int i;
+    std::vector<unsigned> markers = groups;
+    for (unsigned i = 1; i < markers.size(); ++i)
+        markers[i] += markers[i - 1];
 
-    for (i = 0; i < count; ++i) 
+    if (!markers.empty())
+    {
+        fputs(cols[cols_pos], stderr);
+        cols_pos = (cols_pos + 1) % cols_size;
+    }
+
+    for (unsigned i = 0; i < count; ++i)
     {
         if (cursor == data_len)
             break;
-        if (pbyte_len == 0) 
+        if (!markers.empty() && markers[0] == i)
+        {
+            while (!markers.empty() && markers[0] == i)
+                markers.erase(markers.begin());
+            if (markers.empty())
+                fputs("\033[39m\033[49m", stderr);
+            else
+            {
+                fputs(cols[cols_pos], stderr);
+                cols_pos = (cols_pos + 1) % cols_size;
+            }
+        }
+        if (pbyte_len == 0)
         {
             pbyte_len = 8;
             pbyte = data[cursor++];
-            putc(' ', stderr);
+            // putc(' ', stderr);
         }
         putc((pbyte & 0x80) ? '1' : '0', stderr);
         pbyte <<= 1;
@@ -89,6 +117,49 @@ void Input::debug_dump_next_bits(const char* desc, int count) const
     putc('\n', stderr);
 }
 
+void Input::debug_find_sequence(const char* pattern) const
+{
+    // Build a regexp with the pattern
+    regex_t compiled;
+    if (int code = regcomp(&compiled, pattern, REG_EXTENDED))
+    {
+        size_t size = regerror(code, &compiled, nullptr, 0);
+        char* buf = new char[size];
+        regerror(code, &compiled, buf, size);
+        std::string msg(buf);
+        delete[] buf;
+        throw std::runtime_error(msg);
+    }
+
+    // Build a string with '0' and '1' for all remaining bits in the input
+    std::string haystack;
+    size_t cursor = s4_cursor;
+    int pbyte = this->pbyte;
+    int pbyte_len = this->pbyte_len;
+    while (true)
+    {
+        if (cursor == data_len)
+            break;
+        if (pbyte_len == 0)
+        {
+            pbyte_len = 8;
+            pbyte = data[cursor++];
+        }
+        haystack += (pbyte & 0x80) ? '1' : '0';
+        pbyte <<= 1;
+        --pbyte_len;
+    }
+
+    // Match the pattern
+    regmatch_t matches[2];
+    if (regexec(&compiled, haystack.c_str(), 2, matches, 0) != REG_NOMATCH)
+    {
+        fprintf(stderr, "'%s' found at position +%u\n", pattern, (unsigned)matches[0].rm_so);
+    } else {
+        fprintf(stderr, "'%s' not found\n", pattern);
+    }
+}
+
 void Input::parse_error(const char* fmt, ...) const
 {
     char* context;
@@ -304,6 +375,9 @@ bool Input::decode_compressed_base(Varinfo info, uint32_t& base, uint32_t& diffb
     if (missing && diffbits != 0)
         error_consistency::throwf("When decoding compressed BUFR data, the difference bit length must be 0 (and not %d like in this case) when the base value is missing", diffbits);
 
+    TRACE("Input:decode_compressed_base:decoded base %u diffbits %u (%smissing) for %01d%02d%03d %s\n",
+            (unsigned)base, (unsigned)diffbits, missing ? "" : "not ", WR_VAR_FXY(info->code), info->unit);
+
     return missing;
 }
 
@@ -323,20 +397,23 @@ void Input::decode_compressed_number(Var& dest, uint32_t base, unsigned diffbits
     } else {
         // Compute the value for this subset
         uint32_t newval = base + diff;
-        double dval = info->decode_binary(newval);
-        TRACE("Input:decode_number:decoded diffbits %u %u+%u=%u->%f %01d%02d%03d %s\n",
-                diffbits, base, diff, newval, dval, WR_VAR_FXY(info->code), info->unit);
+        if (newval == all_ones(info->bit_len))
+            dest.unset();
+        else
+        {
+            double dval = info->decode_binary(newval);
+            TRACE("Input:decode_compressed_number:decoded diffbits %u %u+%u=%u->%f %01d%02d%03d %s\n",
+                    diffbits, base, diff, newval, dval, WR_VAR_FXY(info->code), info->unit);
 
-        /* Create the new Var */
-        dest.setd(dval);
+            /* Create the new Var */
+            dest.setd(dval);
+        }
     }
 }
 
-void Input::decode_compressed_number(Varinfo info, const bulletin::AssociatedField& associated_field, unsigned subsets, std::function<void(unsigned, Var&&)> dest)
+void Input::decode_compressed_number_af(Varinfo info, const bulletin::AssociatedField& associated_field, unsigned subsets, std::function<void(unsigned, Var&&)> dest)
 {
-    Var var(info);
-
-    // debug_dump_next_bits("DECODE NUMBER: ", 30);
+    // debug_dump_next_bits("Input:decode_compressed_base:", 500, {associated_field.bit_count, 6, info->bit_len, 6});
 
     /* I could not find any specification describing the behaviour of associated fields in compressed BUFRs.
      *
@@ -358,37 +435,27 @@ void Input::decode_compressed_number(Varinfo info, const bulletin::AssociatedFie
     /// Number of bits used to encode the associated field differences
     uint32_t af_diffbits = get_bits(6);
 
-    // Data field base value
-    uint32_t base = get_bits(info->bit_len);
-
-    //TRACE("datasec:decode_b_num:reading %s (%s), size %d, scale %d, starting point %d\n", info->desc, info->bufr_unit, info->bit_len, info->scale, base);
-
-    /* Check if there are bits which are not 1 (that is, if the value is present) */
-    bool missing = (base == all_ones(info->bit_len));
-
-    /*bufr_decoder_debug(decoder, "  %s: %d%s\n", info.desc, base, info.type);*/
-    //TRACE("datasec:decode_b_num:len %d base %d info-len %d info-desc %s\n", info->bit_len, base, info->bit_len, info->desc);
-
-    /* Store the variable that we found */
-
-    /* If compression is in use, then we just decoded the base value.  Now
-     * we need to decode all the offsets */
-
-    /* Decode the number of bits (encoded in 6 bits) that these difference
-     * values occupy */
-    uint32_t diffbits = get_bits(6);
-    if (missing && diffbits != 0)
-        error_consistency::throwf("When decoding compressed BUFR data, the difference bit length must be 0 (and not %d like in this case) when the base value is missing", diffbits);
-
-    //TRACE("Compressed number, base value %d diff bits %d\n", base, diffbits);
-
-    for (unsigned i = 0; i < subsets; ++i)
+    if (af_base == all_ones(associated_field.bit_count))
     {
-        uint32_t af_value = af_base + get_bits(af_diffbits);
-        decode_compressed_number(var, base, diffbits);
-        std::unique_ptr<Var> af(associated_field.make_attribute(af_value));
-        if (af.get()) var.seta(std::move(af));
-        dest(i, std::move(var));
+        // Associated field is missing
+        decode_compressed_number(info, subsets, dest);
+    } else {
+        Var var(info);
+
+        std::vector<std::unique_ptr<Var>> associated_fields(subsets);
+        for (unsigned i = 0; i < subsets; ++i)
+        {
+            uint32_t diff = get_bits(af_diffbits);
+            uint32_t value = af_base + diff;
+            TRACE("Input:decode_compressed_base:decoded af %ubits %u+%u=%u\n", af_diffbits, af_base, diff, value);
+            associated_fields[i] = associated_field.make_attribute(value);
+        }
+
+        decode_compressed_number(info, subsets, [&](unsigned subset, Var&& var) {
+            if (associated_fields[subset].get())
+                var.seta(std::move(associated_fields[subset]));
+            dest(subset, std::move(var));
+        });
     }
 }
 
@@ -450,16 +517,11 @@ void Input::decode_string(Varinfo info, unsigned subsets, std::function<void(uns
     {
         Var var(info);
 
-        /* For compressed strings, the reference value must be all zeros */
-        for (size_t i = 0; i < len; ++i)
-            if (str[i] != 0)
-                error_unimplemented::throwf("compressed strings with %d bit deltas have non-zero reference value", diffbits);
-
         /* Let's also check that the number of
          * difference characters is the same length as
          * the reference string */
-        if (diffbits > len)
-            error_unimplemented::throwf("compressed strings with %zd characters have %d bit deltas (deltas should not be longer than field)", len, diffbits);
+        if (diffbits * 8 > info->bit_len)
+            error_unimplemented::throwf("compressed strings with %d bits have %d bit deltas (deltas should not be longer than field)", info->bit_len, diffbits);
 
         for (unsigned i = 0; i < subsets; ++i)
         {
@@ -512,16 +574,11 @@ void Input::decode_string(Var& dest, unsigned subsets)
         if (!missing)
             dest.setc(str);
     } else {
-        /* For compressed strings, the reference value must be all zeros */
-        for (size_t i = 0; i < len; ++i)
-            if (str[i] != 0)
-                error_unimplemented::throwf("compressed strings with %d bit deltas have non-zero reference value", diffbits);
-
         /* Let's also check that the number of
          * difference characters is the same length as
          * the reference string */
-        if (diffbits > len)
-            error_unimplemented::throwf("compressed strings with %zd characters have %d bit deltas (deltas should not be longer than field)", len, diffbits);
+        if (diffbits * 8 > info->bit_len)
+            error_unimplemented::throwf("compressed strings with %d bits have %d bit deltas (deltas should not be longer than field)", info->bit_len, diffbits);
 
         // Set the variable value
         if (decode_string(diffbits * 8, str, len))
@@ -613,16 +670,12 @@ void Input::decode_string(Varinfo info, unsigned subsets, DispatchToSubsets& des
         // Add the same string to all the subsets
         dest.add_same(Var(info, str));
     } else {
-        /* For compressed strings, the reference value must be all zeros */
-        for (size_t i = 0; i < len; ++i)
-            if (str[i] != 0)
-                error_unimplemented::throwf("compressed strings with %d bit deltas have non-zero reference value", diffbits);
-
         /* Let's also check that the number of
          * difference characters is the same length as
          * the reference string */
-        if (diffbits > len)
-            error_unimplemented::throwf("compressed strings with %zd characters have %d bit deltas (deltas should not be longer than field)", len, diffbits);
+        if (diffbits * 8 > info->bit_len)
+            error_unimplemented::throwf("compressed strings with %d bits have %d bit deltas (deltas should not be longer than field)",
+                    info->bit_len, diffbits * 8);
 
         for (unsigned i = 0; i < subsets; ++i)
         {
