@@ -10,7 +10,6 @@
 #include <memory>
 
 namespace wreport {
-struct DTable;
 
 /**
  * Storage for the decoded data of a BUFR or CREX message.
@@ -27,8 +26,9 @@ struct DTable;
  * Extra values like quality control statistics or replaced values are
  * represented as 'attributes' to the wreport::Var objects.
  */
-struct Bulletin
+class Bulletin
 {
+public:
     /**
      * Input file name (optional).
      *
@@ -99,20 +99,18 @@ struct Bulletin
      */
     uint8_t update_sequence_number = 0;
 
-    /**
-     * Most typical time for the BUFR message contents.
-     *
-     * When accuracy of the time does not define a time unit, then the value
-     * for this unit shall be set to zero (e.g. for a SYNOP observation at 09
-     * UTC, minute = 0, second = 0).
-     * @{ */
+    /// Reference year in bulletin header
     uint16_t rep_year = 0;
+    /// Reference month in bulletin header
     uint8_t rep_month = 0;
+    /// Reference day in bulletin header
     uint8_t rep_day = 0;
+    /// Reference hour in bulletin header
     uint8_t rep_hour = 0;
+    /// Reference minute in bulletin header
     uint8_t rep_minute = 0;
+    /// Reference second in bulletin header
     uint8_t rep_second = 0;
-    /** @} */
 
     /// Varcode and opcode tables used for encoding or decoding
     Tables tables;
@@ -198,8 +196,9 @@ struct Bulletin
 
 
 /// Options used to configure BUFR decoding
-struct BufrCodecOptions
+class BufrCodecOptions
 {
+public:
     /**
      * By default (false) undefined attributes are not added to variables, and
      * there is no difference between an undefined or a missing attribute.
@@ -226,8 +225,9 @@ protected:
 
 
 /// BUFR bulletin implementation
-struct BufrBulletin : public Bulletin
+class BufrBulletin : public Bulletin
 {
+public:
     /// BUFR edition number
     uint8_t edition_number = 4;
 
@@ -393,8 +393,9 @@ protected:
 
 
 /// CREX bulletin implementation
-struct CrexBulletin : public Bulletin
+class CrexBulletin : public Bulletin
 {
+public:
     /// CREX Edition number
     uint8_t edition_number = 2;
 
