@@ -163,7 +163,7 @@ void assert_true(const A& actual)
     std::stringstream ss;
     ss << "actual value " << actual << " is not true";
     throw TestFailed(ss.str());
-};
+}
 
 void assert_true(std::nullptr_t actual);
 
@@ -175,10 +175,49 @@ void assert_false(const A& actual)
     std::stringstream ss;
     ss << "actual value " << actual << " is not false";
     throw TestFailed(ss.str());
-};
+}
 
 void assert_false(std::nullptr_t actual);
 
+template<typename LIST>
+static inline void _format_list(std::ostream& o, const LIST& list) {
+    bool first = true;
+    o << "[";
+    for (const auto& v: list)
+    {
+        if (first)
+            first = false;
+        else
+            o << ", ";
+        o << v;
+    }
+    o << "]";
+}
+
+template<typename T>
+void assert_equal(const std::vector<T>& actual, const std::vector<T>& expected)
+{
+    if (actual == expected) return;
+    std::stringstream ss;
+    ss << "value ";
+    _format_list(ss, actual);
+    ss << " is different than the expected ";
+    _format_list(ss, expected);
+    throw TestFailed(ss.str());
+}
+
+template<typename T>
+void assert_equal(const std::vector<T>& actual, const std::initializer_list<T>& expected)
+{
+    if (actual == expected) return;
+    std::stringstream ss;
+    ss << "value ";
+    _format_list(ss, actual);
+    ss << " is different than the expected ";
+    _format_list(ss, expected);
+    throw TestFailed(ss.str());
+}
+
 /**
  * Test function that ensures that the actual value is the same as a reference
  * one
